pub struct BlockSubscriberContext {
pub mc_block_id: BlockId,
pub mc_is_key_block: bool,
pub is_key_block: bool,
pub block: BlockStuff,
pub archive_data: ArchiveData,
pub delayed: DelayedTasks,
}Fields
mc_block_id: BlockIdRelated masterchain block id.
In case of context for mc block this id is the same as block.id().
mc_is_key_block: boolRelated masterchain block flag.
In case of context for mc block this flag is the same as is_key_block.
is_key_block: boolWhether the block from this context is a key block.
block: BlockStuffParsed block data.
archive_data: ArchiveDataSerialized block data.
delayed: DelayedTasksDelayed tasks to wait before commit.