pub struct StarterConfig {
pub custom_boot_offset: Option<Duration>,
pub start_from: Option<u32>,
}Fields
custom_boot_offset: Option<Duration>Choose persistent state which is at least this old.
Default: None
start_from: Option<u32>Choose the nearest persistent state strictly before this seqno.
Default: None