pub enum DataRequirement {
Optional,
Expected,
Required,
}Variants
Optional
Data is not required to be present on the neighbour (mostly for polling).
NOTE: Node will not be punished if the data is not present.
Expected
We assume that the node has the data, but it’s not required.
NOTE: Node will be punished as [PunishReason::Dumb] if the data is not present.
Required
Data must be present on the requested neighbour.
NOTE: Node will be punished as [PunishReason::Malicious] if the data is not present.