MempoolGlobalConfig

Struct MempoolGlobalConfig 

pub struct MempoolGlobalConfig {
    pub genesis_info: GenesisInfo,
    pub consensus_config: Option<ConsensusConfig>,
}
Default zeros for start round and genesis time are the same in ConsensusInfo.

This will replace genesis from master chain data only if this has time greater than in mc. Also, this genesis must have round not less than in last applied mc block.

Fields

genesis_info: GenesisInfo

start round must be set to the processed_to_anchor_id from last applied master chain block actual genesis round may be greater (or still equal) after alignment; millis must be set not less than last applied mc block time, or better use actual time

consensus_config: Option<ConsensusConfig>

To restart a stale consensus with a new config, the majority of nodes has to provide new common genesis and settings in a global config file. Then an external message must be sent to update blockchain config contract ASAP in order to issue a key block with updated consensus config and persist it in blockchain state. Until then “mempool” part of the global config file must contain all the same data.

It’s because a block can include any settings only when config contract is called, otherwise contract state will not match. Quite the opposite is a recovery genesis info: it is immediately included into the first master chain block as an “extra” part, and makes it a key block.