pub struct NeighborsConfig {
pub update_interval: Duration,
pub ping_interval: Duration,
pub apply_score_interval: Duration,
pub update_metrics_interval: Duration,
pub keep: usize,
pub max_ping_tasks: usize,
pub default_roundtrip: Duration,
pub send_timeout: Duration,
pub query_timeout: Duration,
pub enable_metrics: bool,
}Fields
update_interval: DurationThe interval at which neighbours list is updated.
Default: 2 minutes.
ping_interval: DurationThe interval at which current neighbours are pinged.
Default: 30 seconds.
apply_score_interval: DurationThe interval at which neighbours score is applied to selection index.
Default: 10 seconds.
update_metrics_interval: DurationThe interval to export neighbours metrics.
Default: 5 seconds.
keep: usizeThe maximum number of neighbours to keep.
Default: 5.
max_ping_tasks: usizeThe maximum number of ping tasks to run concurrently.
Default: 5.
default_roundtrip: DurationThe default roundtrip time to use when a neighbour is added.
Default: 300 ms.
send_timeout: DurationSend timeout (unidirectional).
Default: 500ms.
query_timeout: DurationQuery timeout (bidirectional).
Default: 1s.
enable_metrics: boolWhether to enable Neighbours metrics.
Default: true.