pub struct BlocksGcConfig {
pub ty: BlocksGcType,
pub enable_for_sync: bool,
pub max_blocks_per_batch: Option<usize>,
}Fields
ty: BlocksGcTypeBlocks GC type
before_previous_key_block- on each new key block delete all blocks before the previous onebefore_previous_persistent_state- on each new key block delete all blocks before the previous key block with persistent state
enable_for_sync: boolWhether to enable blocks GC during sync. Default: true
max_blocks_per_batch: Option<usize>Max WriteBatch entries before apply