pub struct BlockchainRpcClient { /* private fields */ }Implementations
Sourceimpl BlockchainRpcClient
impl BlockchainRpcClient
pub fn builder() -> BlockchainRpcClientBuilder<()>
pub fn overlay(&self) -> &PublicOverlay
pub fn overlay_client(&self) -> &PublicOverlayClient
Sourcepub async fn broadcast_external_message(&self, message: &[u8]) -> usize
pub async fn broadcast_external_message(&self, message: &[u8]) -> usize
Broadcasts a message to the current targets list and returns the number of peers the message was delivered to.
pub async fn get_next_key_block_ids( &self, block: &BlockId, max_size: u32, ) -> Result<QueryResponse<KeyBlockIds>, Error>
pub async fn get_block_full( &self, block: &BlockId, requirement: DataRequirement, ) -> Result<BlockDataFullWithNeighbour, Error>
pub async fn get_next_block_full( &self, prev_block: &BlockId, requirement: DataRequirement, ) -> Result<BlockDataFullWithNeighbour, Error>
pub async fn get_key_block_proof( &self, block_id: &BlockId, ) -> Result<QueryResponse<KeyBlockProof>, Error>
pub async fn get_persistent_state_info( &self, block_id: &BlockId, ) -> Result<QueryResponse<PersistentStateInfo>, Error>
pub async fn get_persistent_state_part( &self, neighbour: &Neighbour, block_id: &BlockId, offset: u64, ) -> Result<QueryResponse<Data>, Error>
pub async fn find_persistent_state( &self, block_id: &BlockId, kind: PersistentStateKind, ) -> Result<PendingPersistentState, Error>
pub async fn download_persistent_state<W>( &self, state: PendingPersistentState, output: W, ) -> Result<W, Error>
pub async fn find_archive( &self, mc_seqno: u32, ) -> Result<PendingArchiveResponse, Error>
pub async fn download_archive<W>( &self, archive: PendingArchive, output: W, ) -> Result<W, Error>